@@ -1,5 +1,5 @@
 # Schedule::Load::Hosts::Host.pm -- Loading information about a host
-# $Id: Host.pm,v 1.6 2000/11/03 20:53:32 wsnyder Exp $
+# $Id: Host.pm,v 1.7 2000/11/30 18:14:41 wsnyder Exp $
 ######################################################################
 #
 # This program is Copyright 2000 by Wilson Snyder.
@@ -37,7 +37,7 @@ use Carp;
 #### Configuration Section
 
 # Other configurable settings.
-$VERSION = '1.3';
+$VERSION = '1.4';
 
 ######################################################################
 #### Globals
@@ -123,12 +123,16 @@ sub rating {
 
     my $rate = 1e9;
     # Multiply badness by cpu loading
-    $rate *= ($self->total_pctcpu+1);
+    # Scale it to be between .8 and 1.0, else a large number of inactive jobs would
+    # result in a very good rating, which would make that machine always be picked.
+    $rate *= ((($self->total_pctcpu+1)/100) * 0.2 + 0.8);
     # Multiply that by number of jobs
     $rate *= ($self->adj_load+1);
     # Discount by cpus & frequency
     $rate /= $self->cpus;
     $rate /= $self->max_clock;
+
+    #printf "%f * (%d+%d+1) / %f / %f = %f\n", ($self->total_pctcpu+1), $self->report_load, $self->adj_load, $self->cpus, $self->max_clock, $rate if $Debug;
     return ($rate>0)?log($rate):0;	# Make a more readable number
 }
 
